PullSubscribeOptions

Struct PullSubscribeOptions 

pub struct PullSubscribeOptions { /* private fields */ }
👎Deprecated since 0.26.0:

use the async-nats crate instead

Options to configure Pull Subscription

Implementations

Source

impl PullSubscribeOptions

pub fn new() -> PullSubscribeOptions

👎Deprecated since 0.26.0:

use the async-nats crate instead

creates new options

pub fn bind_stream(self, stream_name: String) -> Self

👎Deprecated since 0.26.0:

use the async-nats crate instead

Binds subscription explicitly to a stream. If not specified, stream will be looked up based on the subject provided.

pub fn consumer_config(self, consumer_config: ConsumerConfig) -> Self

👎Deprecated since 0.26.0:

use the async-nats crate instead

when creating Pull Subscription to not existing consumer Consumer Configuration can be specified will apply only if bind_stream is not called and consumer doesn’t exist.

pub fn durable_name(self, consumer_name: String) -> Self

👎Deprecated since 0.26.0:

use the async-nats crate instead

define consumer name