pub struct ObjectInfo {
pub name: String,
pub description: Option<String>,
pub link: Option<ObjectLink>,
pub bucket: String,
pub nuid: String,
pub size: usize,
pub chunks: usize,
pub modified: DateTime,
pub digest: String,
pub deleted: bool,
}use the async-nats crate instead
unstable only.Expand description
Meta and instance information about an object.
Fields
name: Stringuse the async-nats crate instead
Name of the object
description: Option<String>use the async-nats crate instead
A short human readable description of the object.
link: Option<ObjectLink>use the async-nats crate instead
Link this object points to, if any.
bucket: Stringuse the async-nats crate instead
Name of the bucket the object is stored in.
nuid: Stringuse the async-nats crate instead
Unique identifier used to uniquely identify this version of the object.
size: usizeuse the async-nats crate instead
Size in bytes of the object.
chunks: usizeuse the async-nats crate instead
Number of chunks the object is stored in.
modified: DateTimeuse the async-nats crate instead
Date and time the object was last modified.
digest: Stringuse the async-nats crate instead
Digest of the object stream.
deleted: booluse the async-nats crate instead
Set to true if the object has been deleted.