pub struct BatchOptions {
pub batch: usize,
pub expires: Option<usize>,
pub no_wait: bool,
}👎Deprecated since 0.26.0:
use the async-nats crate instead
Used for next Pull Request for Pull Consumer
Fields
batch: usize👎Deprecated since 0.26.0:
use the async-nats crate instead
The number of messages that are being requested to be delivered.
expires: Option<usize>👎Deprecated since 0.26.0:
use the async-nats crate instead
The optional number of nanoseconds that the server will store this next request for before forgetting about the pending batch size.
no_wait: bool👎Deprecated since 0.26.0:
use the async-nats crate instead
This optionally causes the server not to store this pending request at all, but when there are no messages to deliver will send a nil bytes message with a Status header of 404, this way you can know when you reached the end of the stream for example. A 409 is returned if the Consumer has reached MaxAckPending limits.